@@ -2,4 +2,4 @@ from .__version__ import __version__
 from .interface import WriteError, RemoteStorage, StorageLevel
 from .exceptions import *
 from .local import *
-from .ssh import SSHLocation
+from .remote import *
